@@ -29,6 +29,7 @@ from .literals import (
     GoogleAnalyticsConnectorOperatorType,
     InforNexusConnectorOperatorType,
     MarketoConnectorOperatorType,
+    OAuth2CustomPropTypeType,
     OAuth2GrantTypeType,
     OperatorPropertiesKeysType,
     OperatorsType,
@@ -150,6 +151,7 @@ __all__ = (
     "MarketoDestinationPropertiesTypeDef",
     "MarketoSourcePropertiesTypeDef",
     "OAuth2CredentialsTypeDef",
+    "OAuth2CustomParameterTypeDef",
     "OAuth2DefaultsTypeDef",
     "OAuth2PropertiesTypeDef",
     "OAuthCredentialsTypeDef",
@@ -1448,6 +1450,20 @@ OAuth2CredentialsTypeDef = TypedDict(
     total=False,
 )
 
+OAuth2CustomParameterTypeDef = TypedDict(
+    "OAuth2CustomParameterTypeDef",
+    {
+        "key": str,
+        "isRequired": bool,
+        "label": str,
+        "description": str,
+        "isSensitiveField": bool,
+        "connectorSuppliedValues": List[str],
+        "type": OAuth2CustomPropTypeType,
+    },
+    total=False,
+)
+
 OAuth2DefaultsTypeDef = TypedDict(
     "OAuth2DefaultsTypeDef",
     {
@@ -1455,17 +1471,30 @@ OAuth2DefaultsTypeDef = TypedDict(
         "tokenUrls": List[str],
         "authCodeUrls": List[str],
         "oauth2GrantTypesSupported": List[OAuth2GrantTypeType],
+        "oauth2CustomProperties": List["OAuth2CustomParameterTypeDef"],
     },
     total=False,
 )
 
-OAuth2PropertiesTypeDef = TypedDict(
-    "OAuth2PropertiesTypeDef",
+_RequiredOAuth2PropertiesTypeDef = TypedDict(
+    "_RequiredOAuth2PropertiesTypeDef",
     {
         "tokenUrl": str,
         "oAuth2GrantType": OAuth2GrantTypeType,
     },
 )
+_OptionalOAuth2PropertiesTypeDef = TypedDict(
+    "_OptionalOAuth2PropertiesTypeDef",
+    {
+        "tokenUrlCustomProperties": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class OAuth2PropertiesTypeDef(_RequiredOAuth2PropertiesTypeDef, _OptionalOAuth2PropertiesTypeDef):
+    pass
+
 
 _RequiredOAuthCredentialsTypeDef = TypedDict(
     "_RequiredOAuthCredentialsTypeDef",
